"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    domain_name: str,
    account_number: str = None,
    additional_information: str = None,
    party_type: str = None,
    business_name: str = None,
    first_name: str = None,
    middle_name: str = None,
    last_name: str = None,
    birth_date: str = None,
    gender: str = None,
    phone_number: str = None,
    mobile_phone_number: str = None,
    home_phone_number: str = None,
    business_phone_number: str = None,
    email_address: str = None,
    personal_email_address: str = None,
    business_email_address: str = None,
    address: Dict = None,
    shipping_address: Dict = None,
    mailing_address: Dict = None,
    billing_address: Dict = None,
    attributes: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a standard profile. A standard profile represents the following attributes for a customer profile in a domain.

    Args:
        domain_name(str): The unique name of the domain.
        account_number(str, optional): A unique account number that you have given to the customer. Defaults to None.
        additional_information(str, optional): Any additional information relevant to the customer’s profile. Defaults to None.
        party_type(str, optional): The type of profile used to describe the customer. Defaults to None.
        business_name(str, optional): The name of the customer’s business. Defaults to None.
        first_name(str, optional): The customer’s first name. Defaults to None.
        middle_name(str, optional): The customer’s middle name. Defaults to None.
        last_name(str, optional): The customer’s last name. Defaults to None.
        birth_date(str, optional): The customer’s birth date. . Defaults to None.
        gender(str, optional): The gender with which the customer identifies. . Defaults to None.
        phone_number(str, optional): The customer’s phone number, which has not been specified as a mobile, home, or business number. . Defaults to None.
        mobile_phone_number(str, optional): The customer’s mobile phone number. Defaults to None.
        home_phone_number(str, optional): The customer’s home phone number. Defaults to None.
        business_phone_number(str, optional): The customer’s business phone number. Defaults to None.
        email_address(str, optional): The customer’s email address, which has not been specified as a personal or business address. . Defaults to None.
        personal_email_address(str, optional): The customer’s personal email address. Defaults to None.
        business_email_address(str, optional): The customer’s business email address. Defaults to None.
        address(Dict, optional): A generic address associated with the customer that is not mailing, shipping, or billing. Defaults to None.
        shipping_address(Dict, optional): The customer’s shipping address. Defaults to None.
        mailing_address(Dict, optional): The customer’s mailing address. Defaults to None.
        billing_address(Dict, optional): The customer’s billing address. Defaults to None.
        attributes(Dict, optional): A key value pair of attributes of a customer profile. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.init.create(ctx, domain_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.init.create domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="create_profile",
        op_kwargs={
            "DomainName": domain_name,
            "AccountNumber": account_number,
            "AdditionalInformation": additional_information,
            "PartyType": party_type,
            "BusinessName": business_name,
            "FirstName": first_name,
            "MiddleName": middle_name,
            "LastName": last_name,
            "BirthDate": birth_date,
            "Gender": gender,
            "PhoneNumber": phone_number,
            "MobilePhoneNumber": mobile_phone_number,
            "HomePhoneNumber": home_phone_number,
            "BusinessPhoneNumber": business_phone_number,
            "EmailAddress": email_address,
            "PersonalEmailAddress": personal_email_address,
            "BusinessEmailAddress": business_email_address,
            "Address": address,
            "ShippingAddress": shipping_address,
            "MailingAddress": mailing_address,
            "BillingAddress": billing_address,
            "Attributes": attributes,
        },
    )


async def delete(hub, ctx, profile_id: str, domain_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the standard customer profile and all data pertaining to the profile.

    Args:
        profile_id(str): The unique identifier of a customer profile.
        domain_name(str): The unique name of the domain.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.init.delete(
                ctx, profile_id=value, domain_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.init.delete profile_id=value, domain_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="delete_profile",
        op_kwargs={"ProfileId": profile_id, "DomainName": domain_name},
    )


async def merge(
    hub,
    ctx,
    domain_name: str,
    main_profile_id: str,
    profile_ids_to_be_merged: List,
    field_source_profile_ids: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    This API is in preview release for Amazon Connect and subject to change. Runs an AWS Lambda job that does the following:   All the profileKeys in the ProfileToBeMerged will be moved to the main profile.   All the objects in the ProfileToBeMerged will be moved to the main profile.   All the ProfileToBeMerged will be deleted at the end.   All the profileKeys in the ProfileIdsToBeMerged will be moved to the main profile.   Standard fields are merged as follows:   Fields are always "union"-ed if there are no conflicts in standard fields or attributeKeys.   When there are conflicting fields:   If no SourceProfileIds entry is specified, the main Profile value is always taken.    If a SourceProfileIds entry is specified, the specified profileId is always taken, even if it is a NULL value.       You can use MergeProfiles together with GetMatches, which returns potentially matching profiles, or use it with the results of another matching system. After profiles have been merged, they cannot be separated (unmerged).

    Args:
        domain_name(str): The unique name of the domain.
        main_profile_id(str): The identifier of the profile to be taken.
        profile_ids_to_be_merged(List): The identifier of the profile to be merged into MainProfileId.
        field_source_profile_ids(Dict, optional): The identifiers of the fields in the profile that has the information you want to apply to the merge. For example, say you want to merge EmailAddress from Profile1 into MainProfile. This would be the identifier of the EmailAddress field in Profile1. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.init.merge(
                ctx, domain_name=value, main_profile_id=value, profile_ids_to_be_merged=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.init.merge domain_name=value, main_profile_id=value, profile_ids_to_be_merged=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="merge_profiles",
        op_kwargs={
            "DomainName": domain_name,
            "MainProfileId": main_profile_id,
            "ProfileIdsToBeMerged": profile_ids_to_be_merged,
            "FieldSourceProfileIds": field_source_profile_ids,
        },
    )


async def search(
    hub,
    ctx,
    domain_name: str,
    key_name: str,
    values: List,
    next_token: str = None,
    max_results: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Searches for profiles within a specific domain name using name, phone number, email address, account number, or a custom defined index.

    Args:
        next_token(str, optional): The pagination token from the previous SearchProfiles API call. Defaults to None.
        max_results(int, optional): The maximum number of objects returned per page. Defaults to None.
        domain_name(str): The unique name of the domain.
        key_name(str): A searchable identifier of a customer profile. The predefined keys you can use to search include: _account, _profileId, _fullName, _phone, _email, _ctrContactId, _marketoLeadId, _salesforceAccountId, _salesforceContactId, _zendeskUserId, _zendeskExternalId, _serviceNowSystemId.
        values(List): A list of key values.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.init.search(
                ctx, domain_name=value, key_name=value, values=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.init.search domain_name=value, key_name=value, values=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="search_profiles",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "DomainName": domain_name,
            "KeyName": key_name,
            "Values": values,
        },
    )


async def update(
    hub,
    ctx,
    domain_name: str,
    profile_id: str,
    additional_information: str = None,
    account_number: str = None,
    party_type: str = None,
    business_name: str = None,
    first_name: str = None,
    middle_name: str = None,
    last_name: str = None,
    birth_date: str = None,
    gender: str = None,
    phone_number: str = None,
    mobile_phone_number: str = None,
    home_phone_number: str = None,
    business_phone_number: str = None,
    email_address: str = None,
    personal_email_address: str = None,
    business_email_address: str = None,
    address: Dict = None,
    shipping_address: Dict = None,
    mailing_address: Dict = None,
    billing_address: Dict = None,
    attributes: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the properties of a profile. The ProfileId is required for updating a customer profile. When calling the UpdateProfile API, specifying an empty string value means that any existing value will be removed. Not specifying a string value means that any value already there will be kept.

    Args:
        domain_name(str): The unique name of the domain.
        profile_id(str): The unique identifier of a customer profile.
        additional_information(str, optional): Any additional information relevant to the customer’s profile. Defaults to None.
        account_number(str, optional): A unique account number that you have given to the customer. Defaults to None.
        party_type(str, optional): The type of profile used to describe the customer. Defaults to None.
        business_name(str, optional): The name of the customer’s business. Defaults to None.
        first_name(str, optional): The customer’s first name. Defaults to None.
        middle_name(str, optional): The customer’s middle name. Defaults to None.
        last_name(str, optional): The customer’s last name. Defaults to None.
        birth_date(str, optional): The customer’s birth date. . Defaults to None.
        gender(str, optional): The gender with which the customer identifies. . Defaults to None.
        phone_number(str, optional): The customer’s phone number, which has not been specified as a mobile, home, or business number. . Defaults to None.
        mobile_phone_number(str, optional): The customer’s mobile phone number. Defaults to None.
        home_phone_number(str, optional): The customer’s home phone number. Defaults to None.
        business_phone_number(str, optional): The customer’s business phone number. Defaults to None.
        email_address(str, optional): The customer’s email address, which has not been specified as a personal or business address. . Defaults to None.
        personal_email_address(str, optional): The customer’s personal email address. Defaults to None.
        business_email_address(str, optional): The customer’s business email address. Defaults to None.
        address(Dict, optional): A generic address associated with the customer that is not mailing, shipping, or billing. Defaults to None.
        shipping_address(Dict, optional): The customer’s shipping address. Defaults to None.
        mailing_address(Dict, optional): The customer’s mailing address. Defaults to None.
        billing_address(Dict, optional): The customer’s billing address. Defaults to None.
        attributes(Dict, optional): A key value pair of attributes of a customer profile. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.customer_profile.profile.init.update(
                ctx, domain_name=value, profile_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.customer_profile.profile.init.update domain_name=value, profile_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="customer-profiles",
        operation="update_profile",
        op_kwargs={
            "DomainName": domain_name,
            "ProfileId": profile_id,
            "AdditionalInformation": additional_information,
            "AccountNumber": account_number,
            "PartyType": party_type,
            "BusinessName": business_name,
            "FirstName": first_name,
            "MiddleName": middle_name,
            "LastName": last_name,
            "BirthDate": birth_date,
            "Gender": gender,
            "PhoneNumber": phone_number,
            "MobilePhoneNumber": mobile_phone_number,
            "HomePhoneNumber": home_phone_number,
            "BusinessPhoneNumber": business_phone_number,
            "EmailAddress": email_address,
            "PersonalEmailAddress": personal_email_address,
            "BusinessEmailAddress": business_email_address,
            "Address": address,
            "ShippingAddress": shipping_address,
            "MailingAddress": mailing_address,
            "BillingAddress": billing_address,
            "Attributes": attributes,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, account_id: str, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Removes the entire tag set from the specified S3 Batch Operations job. To use this operation, you must have permission to perform the s3:DeleteJobTagging action. For more information, see Controlling access and labeling jobs using tags in the Amazon S3 User Guide.  Related actions include:    CreateJob     GetJobTagging     PutJobTagging

    Args:
        account_id(str): The account ID associated with the S3 Batch Operations job.
        job_id(str): The ID for the S3 Batch Operations job whose tags you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.job.tagging.delete(
                ctx, account_id=value, job_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.job.tagging.delete account_id=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="delete_job_tagging",
        op_kwargs={"AccountId": account_id, "JobId": job_id},
    )


async def get(hub, ctx, account_id: str, job_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns the tags on an S3 Batch Operations job. To use this operation, you must have permission to perform the s3:GetJobTagging action. For more information, see Controlling access and labeling jobs using tags in the Amazon S3 User Guide.  Related actions include:    CreateJob     PutJobTagging     DeleteJobTagging

    Args:
        account_id(str): The account ID associated with the S3 Batch Operations job.
        job_id(str): The ID for the S3 Batch Operations job whose tags you want to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.job.tagging.get(ctx, account_id=value, job_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.job.tagging.get account_id=value, job_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="get_job_tagging",
        op_kwargs={"AccountId": account_id, "JobId": job_id},
    )


async def put(hub, ctx, account_id: str, job_id: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Sets the supplied tag-set on an S3 Batch Operations job. A tag is a key-value pair. You can associate S3 Batch Operations tags with any job by sending a PUT request against the tagging subresource that is associated with the job. To modify the existing tag set, you can either replace the existing tag set entirely, or make changes within the existing tag set by retrieving the existing tag set using GetJobTagging, modify that tag set, and use this action to replace the tag set with the one you modified. For more information, see Controlling access and labeling jobs using tags in the Amazon S3 User Guide.      If you send this request with an empty tag set, Amazon S3 deletes the existing tag set on the Batch Operations job. If you use this method, you are charged for a Tier 1 Request (PUT). For more information, see Amazon S3 pricing.   For deleting existing tags for your Batch Operations job, a DeleteJobTagging request is preferred because it achieves the same result without incurring charges.   A few things to consider about using tags:   Amazon S3 limits the maximum number of tags to 50 tags per job.   You can associate up to 50 tags with a job as long as they have unique tag keys.   A tag key can be up to 128 Unicode characters in length, and tag values can be up to 256 Unicode characters in length.   The key and values are case sensitive.   For tagging-related restrictions related to characters and encodings, see User-Defined Tag Restrictions in the Billing and Cost Management User Guide.       To use this action, you must have permission to perform the s3:PutJobTagging action. Related actions include:    CreatJob     GetJobTagging     DeleteJobTagging

    Args:
        account_id(str): The account ID associated with the S3 Batch Operations job.
        job_id(str): The ID for the S3 Batch Operations job whose tags you want to replace.
        tags(List): The set of tags to associate with the S3 Batch Operations job.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.s3control.job.tagging.put(
                ctx, account_id=value, job_id=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.s3control.job.tagging.put account_id=value, job_id=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="s3control",
        operation="put_job_tagging",
        op_kwargs={"AccountId": account_id, "JobId": job_id, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(
    hub,
    ctx,
    detector_id: str,
    usage_statistic_type: str,
    usage_criteria: Dict,
    unit: str = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists Amazon GuardDuty usage statistics over the last 30 days for the specified detector ID. For newly enabled detectors or data sources the cost returned will include only the usage so far under 30 days, this may differ from the cost metrics in the console, which projects usage over 30 days to provide a monthly cost estimate. For more information see Understanding How Usage Costs are Calculated.

    Args:
        detector_id(str): The ID of the detector that specifies the GuardDuty service whose usage statistics you want to retrieve.
        usage_statistic_type(str): The type of usage statistics to retrieve.
        usage_criteria(Dict): Represents the criteria used for querying usage.
        unit(str, optional): The currency unit you would like to view your usage statistics in. Current valid values are USD. Defaults to None.
        max_results(int, optional): The maximum number of results to return in the response. Defaults to None.
        next_token(str, optional): A token to use for paginating results that are returned in the response. Set the value of this parameter to null for the first request to a list action. For subsequent calls, use the NextToken value returned from the previous request to continue listing results after the first page. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.guardduty.usage_statistic.get_all(
                ctx, detector_id=value, usage_statistic_type=value, usage_criteria=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.guardduty.usage_statistic.get_all detector_id=value, usage_statistic_type=value, usage_criteria=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="guardduty",
        operation="get_usage_statistics",
        op_kwargs={
            "DetectorId": detector_id,
            "UsageStatisticType": usage_statistic_type,
            "UsageCriteria": usage_criteria,
            "Unit": unit,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def deliver(hub, ctx, delivery_channel_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Schedules delivery of a configuration snapshot to the Amazon S3 bucket in the specified delivery channel. After the delivery has started, AWS Config sends the following notifications using an Amazon SNS topic that you have specified.   Notification of the start of the delivery.   Notification of the completion of the delivery, if the delivery was successfully completed.   Notification of delivery failure, if the delivery failed.

    Args:
        delivery_channel_name(str): The name of the delivery channel through which the snapshot is delivered.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.config.config.snapshot.deliver(ctx, delivery_channel_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.config.config.snapshot.deliver delivery_channel_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="config",
        operation="deliver_config_snapshot",
        op_kwargs={"deliveryChannelName": delivery_channel_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(hub, ctx, stream_name: str, tags: Dict) -> None:
    r"""
    **Autogenerated function**

    Adds or updates tags for the specified Kinesis data stream. Each time you invoke this operation, you can specify up to 10 tags. If you want to add more than 10 tags to your stream, you can invoke this operation multiple times. In total, each stream can have up to 50 tags. If tags have already been assigned to the stream, AddTagsToStream overwrites any existing tags that correspond to the specified tag keys.  AddTagsToStream has a limit of five transactions per second per account.

    Args:
        stream_name(str): The name of the stream.
        tags(Dict): A set of up to 10 key-value pairs to use to create the tags.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesis.tags.to_stream.add(ctx, stream_name=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesis.tags.to_stream.add stream_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesis",
        operation="add_tags_to_stream",
        op_kwargs={"StreamName": stream_name, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    kubernetes_version: str = None,
    max_results: int = None,
    next_token: str = None,
    addon_name: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Describes the Kubernetes versions that the add-on can be used with.

    Args:
        kubernetes_version(str, optional): The Kubernetes versions that the add-on can be used with. Defaults to None.
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated DescribeAddonVersionsRequest where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.  This token should be treated as an opaque identifier that is used only to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.
        addon_name(str, optional): The name of the add-on. The name must match one of the names returned by  ListAddons . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.eks.addon.version.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.eks.addon.version.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="eks",
        operation="describe_addon_versions",
        op_kwargs={
            "kubernetesVersion": kubernetes_version,
            "maxResults": max_results,
            "nextToken": next_token,
            "addonName": addon_name,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, image_build_version_arn: str, client_token: str) -> Dict:
    r"""
    **Autogenerated function**

    CancelImageCreation cancels the creation of Image. This operation can only be used on images in a non-terminal state.

    Args:
        image_build_version_arn(str): The Amazon Resource Name (ARN) of the image whose creation you want to cancel.
        client_token(str): The idempotency token used to make this request idempotent.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.imagebuilder.image.creation.cancel(
                ctx, image_build_version_arn=value, client_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.imagebuilder.image.creation.cancel image_build_version_arn=value, client_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="imagebuilder",
        operation="cancel_image_creation",
        op_kwargs={
            "imageBuildVersionArn": image_build_version_arn,
            "clientToken": client_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import List


async def add(hub, ctx, resource_name: str, tags: List) -> None:
    r"""
    **Autogenerated function**

    Adds metadata tags to an Amazon DocumentDB resource. You can use these tags with cost allocation reporting to track costs that are associated with Amazon DocumentDB resources or in a Condition statement in an Identity and Access Management (IAM) policy for Amazon DocumentDB.

    Args:
        resource_name(str): The Amazon DocumentDB resource that the tags are added to. This value is an Amazon Resource Name .
        tags(List): The tags to be assigned to the Amazon DocumentDB resource.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.docdb.tags.to_resource.add(ctx, resource_name=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.docdb.tags.to_resource.add resource_name=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="docdb",
        operation="add_tags_to_resource",
        op_kwargs={"ResourceName": resource_name, "Tags": tags},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, command_id: str, instance_ids: List = None) -> Dict:
    r"""
    **Autogenerated function**

    Attempts to cancel the command specified by the Command ID. There is no guarantee that the command will be terminated and the underlying process stopped.

    Args:
        command_id(str): The ID of the command you want to cancel.
        instance_ids(List, optional): (Optional) A list of instance IDs on which you want to cancel the command. If not provided, the command is canceled on every instance on which it was requested. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.command.init.cancel(ctx, command_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.command.init.cancel command_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="cancel_command",
        op_kwargs={"CommandId": command_id, "InstanceIds": instance_ids},
    )


async def list_all(
    hub,
    ctx,
    command_id: str = None,
    instance_id: str = None,
    max_results: int = None,
    next_token: str = None,
    filters: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists the commands requested by users of the account.

    Args:
        command_id(str, optional): (Optional) If provided, lists only the specified command. Defaults to None.
        instance_id(str, optional): (Optional) Lists commands issued against this instance ID.  You can't specify an instance ID in the same command that you specify Status = Pending. This is because the command hasn't reached the instance yet. . Defaults to None.
        max_results(int, optional): (Optional) The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): (Optional) The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        filters(List, optional): (Optional) One or more filters. Use a filter to return a more specific list of results. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.command.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.command.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="list_commands",
        op_kwargs={
            "CommandId": command_id,
            "InstanceId": instance_id,
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )


async def send(
    hub,
    ctx,
    document_name: str,
    instance_ids: List = None,
    targets: List = None,
    document_version: str = None,
    document_hash: str = None,
    document_hash_type: str = None,
    timeout_seconds: int = None,
    comment: str = None,
    parameters: Dict = None,
    output_s3_region: str = None,
    output_s3_bucket_name: str = None,
    output_s3_key_prefix: str = None,
    max_concurrency: str = None,
    max_errors: str = None,
    service_role_arn: str = None,
    notification_config: Dict = None,
    cloud_watch_output_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Runs commands on one or more managed instances.

    Args:
        instance_ids(List, optional): The IDs of the instances where the command should run. Specifying instance IDs is most useful when you are targeting a limited number of instances, though you can specify up to 50 IDs. To target a larger number of instances, or if you prefer not to list individual instance IDs, we recommend using the Targets option instead. Using Targets, which accepts tag key-value pairs to identify the instances to send commands to, you can a send command to tens, hundreds, or thousands of instances at once. For more information about how to use targets, see Using targets and rate controls to send commands to a fleet in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        targets(List, optional): An array of search criteria that targets instances using a Key,Value combination that you specify. Specifying targets is most useful when you want to send a command to a large number of instances at once. Using Targets, which accepts tag key-value pairs to identify instances, you can send a command to tens, hundreds, or thousands of instances at once. To send a command to a smaller number of instances, you can use the InstanceIds option instead. For more information about how to use targets, see Sending commands to a fleet in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        document_name(str): The name of the Amazon Web Services Systems Manager document (SSM document) to run. This can be a public document or a custom document. To run a shared document belonging to another account, specify the document ARN. For more information about how to use shared documents, see Using shared SSM documents in the Amazon Web Services Systems Manager User Guide.
        document_version(str, optional): The SSM document version to use in the request. You can specify $DEFAULT, $LATEST, or a specific version number. If you run commands by using the Command Line Interface (Amazon Web Services CLI), then you must escape the first two options by using a backslash. If you specify a version number, then you don't need to use the backslash. For example: --document-version "\$DEFAULT" --document-version "\$LATEST" --document-version "3". Defaults to None.
        document_hash(str, optional): The Sha256 or Sha1 hash created by the system when the document was created.   Sha1 hashes have been deprecated. . Defaults to None.
        document_hash_type(str, optional): Sha256 or Sha1.  Sha1 hashes have been deprecated. . Defaults to None.
        timeout_seconds(int, optional): If this time is reached and the command hasn't already started running, it won't run. Defaults to None.
        comment(str, optional): User-specified information about the command, such as a brief description of what the command should do. Defaults to None.
        parameters(Dict, optional): The required and optional parameters specified in the document being run. Defaults to None.
        output_s3_region(str, optional): (Deprecated) You can no longer specify this parameter. The system ignores it. Instead, Systems Manager automatically determines the Region of the S3 bucket. Defaults to None.
        output_s3_bucket_name(str, optional): The name of the S3 bucket where command execution responses should be stored. Defaults to None.
        output_s3_key_prefix(str, optional): The directory structure within the S3 bucket where the responses should be stored. Defaults to None.
        max_concurrency(str, optional): (Optional) The maximum number of instances that are allowed to run the command at the same time. You can specify a number such as 10 or a percentage such as 10%. The default value is 50. For more information about how to use MaxConcurrency, see Using concurrency controls in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        max_errors(str, optional): The maximum number of errors allowed without the command failing. When the command fails one more time beyond the value of MaxErrors, the systems stops sending the command to additional targets. You can specify a number like 10 or a percentage like 10%. The default value is 0. For more information about how to use MaxErrors, see Using error controls in the Amazon Web Services Systems Manager User Guide. Defaults to None.
        service_role_arn(str, optional): The ARN of the Identity and Access Management (IAM) service role to use to publish Amazon Simple Notification Service (Amazon SNS) notifications for Run Command commands. Defaults to None.
        notification_config(Dict, optional): Configurations for sending notifications. Defaults to None.
        cloud_watch_output_config(Dict, optional): Enables Amazon Web Services Systems Manager to send Run Command output to Amazon CloudWatch Logs. Run Command is a capability of Amazon Web Services Systems Manager. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.command.init.send(ctx, document_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.command.init.send document_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="send_command",
        op_kwargs={
            "InstanceIds": instance_ids,
            "Targets": targets,
            "DocumentName": document_name,
            "DocumentVersion": document_version,
            "DocumentHash": document_hash,
            "DocumentHashType": document_hash_type,
            "TimeoutSeconds": timeout_seconds,
            "Comment": comment,
            "Parameters": parameters,
            "OutputS3Region": output_s3_region,
            "OutputS3BucketName": output_s3_bucket_name,
            "OutputS3KeyPrefix": output_s3_key_prefix,
            "MaxConcurrency": max_concurrency,
            "MaxErrors": max_errors,
            "ServiceRoleArn": service_role_arn,
            "NotificationConfig": notification_config,
            "CloudWatchOutputConfig": cloud_watch_output_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe_all(
    hub,
    ctx,
    vpc_id: str,
    dry_run: bool = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    [VPC only] Describes the stale security group rules for security groups in a specified VPC. Rules are stale when they reference a deleted security group in a peer VPC, or a security group in a peer VPC for which the VPC peering connection has been deleted.

    Args:
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request, and provides an error response. If you have the required permissions, the error response is DryRunOperation. Otherwise, it is UnauthorizedOperation. Defaults to None.
        max_results(int, optional): The maximum number of items to return for this request. The request returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a prior call.). Defaults to None.
        vpc_id(str): The ID of the VPC.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ec2.stale_security_group.describe_all(ctx, vpc_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ec2.stale_security_group.describe_all vpc_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ec2",
        operation="describe_stale_security_groups",
        op_kwargs={
            "DryRun": dry_run,
            "MaxResults": max_results,
            "NextToken": next_token,
            "VpcId": vpc_id,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    user_id: str,
    user_name: str,
    engine: str,
    access_string: str,
    passwords: List = None,
    no_password_required: bool = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    For Redis engine version 6.x onwards: Creates a Redis user. For more information, see Using Role Based Access Control (RBAC).

    Args:
        user_id(str): The ID of the user.
        user_name(str): The username of the user.
        engine(str): The current supported value is Redis. .
        passwords(List, optional): Passwords used for this user. You can create up to two passwords for each user. Defaults to None.
        access_string(str): Access permissions string used for this user.
        no_password_required(bool, optional): Indicates a password is not required for this user. Defaults to None.
        tags(List, optional): A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.user.init.create(
                ctx, user_id=value, user_name=value, engine=value, access_string=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.user.init.create user_id=value, user_name=value, engine=value, access_string=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="create_user",
        op_kwargs={
            "UserId": user_id,
            "UserName": user_name,
            "Engine": engine,
            "Passwords": passwords,
            "AccessString": access_string,
            "NoPasswordRequired": no_password_required,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, user_id: str) -> Dict:
    r"""
    **Autogenerated function**

    For Redis engine version 6.x onwards: Deletes a user. The user will be removed from all user groups and in turn removed from all replication groups. For more information, see Using Role Based Access Control (RBAC).

    Args:
        user_id(str): The ID of the user.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.user.init.delete(ctx, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.user.init.delete user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="delete_user",
        op_kwargs={"UserId": user_id},
    )


async def describe_all(
    hub,
    ctx,
    engine: str = None,
    user_id: str = None,
    filters: List = None,
    max_records: int = None,
    marker: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of users.

    Args:
        engine(str, optional): The Redis engine. . Defaults to None.
        user_id(str, optional): The ID of the user. Defaults to None.
        filters(List, optional): Filter to determine the list of User IDs to return. Defaults to None.
        max_records(int, optional): The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a marker is included in the response so that the remaining results can be retrieved. . Defaults to None.
        marker(str, optional): An optional marker returned from a prior request. Use this marker for pagination of results from this operation. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords. >. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.user.init.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.user.init.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="describe_users",
        op_kwargs={
            "Engine": engine,
            "UserId": user_id,
            "Filters": filters,
            "MaxRecords": max_records,
            "Marker": marker,
        },
    )


async def modify(
    hub,
    ctx,
    user_id: str,
    access_string: str = None,
    append_access_string: str = None,
    passwords: List = None,
    no_password_required: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Changes user password(s) and/or access string.

    Args:
        user_id(str): The ID of the user.
        access_string(str, optional): Access permissions string used for this user. Defaults to None.
        append_access_string(str, optional): Adds additional user permissions to the access string. Defaults to None.
        passwords(List, optional): The passwords belonging to the user. You are allowed up to two. Defaults to None.
        no_password_required(bool, optional): Indicates no password is required for the user. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.elasticache.user.init.modify(ctx, user_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.elasticache.user.init.modify user_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="elasticache",
        operation="modify_user",
        op_kwargs={
            "UserId": user_id,
            "AccessString": access_string,
            "AppendAccessString": append_access_string,
            "Passwords": passwords,
            "NoPasswordRequired": no_password_required,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the event stream for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.event.stream.delete(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.event.stream.delete application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="delete_event_stream",
        op_kwargs={"ApplicationId": application_id},
    )


async def get(hub, ctx, application_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves information about the event stream settings for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.event.stream.get(ctx, application_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.event.stream.get application_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="get_event_stream",
        op_kwargs={"ApplicationId": application_id},
    )


async def put(hub, ctx, application_id: str, write_event_stream: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates a new event stream for an application or updates the settings of an existing event stream for an application.

    Args:
        application_id(str): The unique identifier for the application. This identifier is displayed as the Project ID on the Amazon Pinpoint console.
        write_event_stream(Dict): Specifies the Amazon Resource Name (ARN) of an event stream to publish events to and the AWS Identity and Access Management (IAM) role to use when publishing those events.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.pinpoint.event.stream.put(
                ctx, application_id=value, write_event_stream=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.pinpoint.event.stream.put application_id=value, write_event_stream=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="pinpoint",
        operation="put_event_stream",
        op_kwargs={
            "ApplicationId": application_id,
            "WriteEventStream": write_event_stream,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def tag(hub, ctx, workload_arn: str, tags: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Adds one or more tags to the specified resource.

    Args:
        workload_arn(str): The ARN for the workload.
        tags(Dict): The tags for the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.resource.tag(
                ctx, workload_arn=value, tags=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.resource.tag workload_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="tag_resource",
        op_kwargs={"WorkloadArn": workload_arn, "Tags": tags},
    )


async def untag(hub, ctx, workload_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes specified tags from a resource. To specify multiple tags, use separate tagKeys parameters, for example:  DELETE /tags/WorkloadArn?tagKeys=key1&tagKeys=key2

    Args:
        workload_arn(str): The ARN for the workload.
        tag_keys(List): A list of tag keys. Existing tags of the resource whose keys are members of this list are removed from the resource.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.wellarchitected.resource.untag(
                ctx, workload_arn=value, tag_keys=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.wellarchitected.resource.untag workload_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="wellarchitected",
        operation="untag_resource",
        op_kwargs={"WorkloadArn": workload_arn, "TagKeys": tag_keys},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(
    hub,
    ctx,
    type_name: str = None,
    next_token: str = None,
    max_results: int = None,
    aggregator: bool = None,
    sub_type: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Return a list of inventory type names for the account, or return a list of attribute names for a specific Inventory item type.

    Args:
        type_name(str, optional): The type of inventory item to return. Defaults to None.
        next_token(str, optional): The token for the next set of items to return. (You received this token from a previous call.). Defaults to None.
        max_results(int, optional): The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. Defaults to None.
        aggregator(bool, optional): Returns inventory schemas that support aggregation. For example, this call returns the AWS:InstanceInformation type, because it supports aggregation based on the PlatformName, PlatformType, and PlatformVersion attributes. Defaults to None.
        sub_type(bool, optional): Returns the sub-type schema for a specified inventory type. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ssm.inventory.schema.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ssm.inventory.schema.get
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ssm",
        operation="get_inventory_schema",
        op_kwargs={
            "TypeName": type_name,
            "NextToken": next_token,
            "MaxResults": max_results,
            "Aggregator": aggregator,
            "SubType": sub_type,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(
    hub,
    ctx,
    archive_name: str,
    event_source_arn: str,
    description: str = None,
    event_pattern: str = None,
    retention_days: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an archive of events with the specified settings. When you create an archive, incoming events might not immediately start being sent to the archive. Allow a short period of time for changes to take effect. If you do not specify a pattern to filter events sent to the archive, all events are sent to the archive except replayed events. Replayed events are not sent to an archive.

    Args:
        archive_name(str): The name for the archive to create.
        event_source_arn(str): The ARN of the event source associated with the archive.
        description(str, optional): A description for the archive. Defaults to None.
        event_pattern(str, optional): An event pattern to use to filter events sent to the archive. Defaults to None.
        retention_days(int, optional): The number of days to retain events for. Default value is 0. If set to 0, events are retained indefinitely. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.archive.create(
                ctx, archive_name=value, event_source_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.archive.create archive_name=value, event_source_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="create_archive",
        op_kwargs={
            "ArchiveName": archive_name,
            "EventSourceArn": event_source_arn,
            "Description": description,
            "EventPattern": event_pattern,
            "RetentionDays": retention_days,
        },
    )


async def delete(hub, ctx, archive_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified archive.

    Args:
        archive_name(str): The name of the archive to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.archive.delete(ctx, archive_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.archive.delete archive_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="delete_archive",
        op_kwargs={"ArchiveName": archive_name},
    )


async def describe(hub, ctx, archive_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves details about an archive.

    Args:
        archive_name(str): The name of the archive to retrieve.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.archive.describe(ctx, archive_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.archive.describe archive_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="describe_archive",
        op_kwargs={"ArchiveName": archive_name},
    )


async def list_all(
    hub,
    ctx,
    name_prefix: str = None,
    event_source_arn: str = None,
    state: str = None,
    next_token: str = None,
    limit: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists your archives. You can either list all the archives or you can provide a prefix to match to the archive names. Filter parameters are exclusive.

    Args:
        name_prefix(str, optional): A name prefix to filter the archives returned. Only archives with name that match the prefix are returned. Defaults to None.
        event_source_arn(str, optional): The ARN of the event source associated with the archive. Defaults to None.
        state(str, optional): The state of the archive. Defaults to None.
        next_token(str, optional): The token returned by a previous call to retrieve the next set of results. Defaults to None.
        limit(int, optional): The maximum number of results to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.archive.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.archive.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="list_archives",
        op_kwargs={
            "NamePrefix": name_prefix,
            "EventSourceArn": event_source_arn,
            "State": state,
            "NextToken": next_token,
            "Limit": limit,
        },
    )


async def update(
    hub,
    ctx,
    archive_name: str,
    description: str = None,
    event_pattern: str = None,
    retention_days: int = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the specified archive.

    Args:
        archive_name(str): The name of the archive to update.
        description(str, optional): The description for the archive. Defaults to None.
        event_pattern(str, optional): The event pattern to use to filter events sent to the archive. Defaults to None.
        retention_days(int, optional): The number of days to retain events in the archive. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.event.archive.update(ctx, archive_name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.event.archive.update archive_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="events",
        operation="update_archive",
        op_kwargs={
            "ArchiveName": archive_name,
            "Description": description,
            "EventPattern": event_pattern,
            "RetentionDays": retention_days,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def create(hub, ctx, domain_name: str, domain_entry: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Creates one of the following domain name system (DNS) records in a domain DNS zone: Address (A), canonical name (CNAME), mail exchanger (MX), name server (NS), start of authority (SOA), service locator (SRV), or text (TXT). The create domain entry operation supports tag-based access control via resource tags applied to the resource identified by domain name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        domain_name(str): The domain name (e.g., example.com) for which you want to create the domain entry.
        domain_entry(Dict): An array of key-value pairs containing information about the domain entry request.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.domain.entry.create(
                ctx, domain_name=value, domain_entry=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.domain.entry.create domain_name=value, domain_entry=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="create_domain_entry",
        op_kwargs={"domainName": domain_name, "domainEntry": domain_entry},
    )


async def delete(hub, ctx, domain_name: str, domain_entry: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a specific domain entry. The delete domain entry operation supports tag-based access control via resource tags applied to the resource identified by domain name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        domain_name(str): The name of the domain entry to delete.
        domain_entry(Dict): An array of key-value pairs containing information about your domain entries.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.domain.entry.delete(
                ctx, domain_name=value, domain_entry=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.domain.entry.delete domain_name=value, domain_entry=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="delete_domain_entry",
        op_kwargs={"domainName": domain_name, "domainEntry": domain_entry},
    )


async def update(hub, ctx, domain_name: str, domain_entry: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Updates a domain recordset after it is created. The update domain entry operation supports tag-based access control via resource tags applied to the resource identified by domain name. For more information, see the Amazon Lightsail Developer Guide.

    Args:
        domain_name(str): The name of the domain recordset to update.
        domain_entry(Dict): An array of key-value pairs containing information about the domain entry.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lightsail.domain.entry.update(
                ctx, domain_name=value, domain_entry=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lightsail.domain.entry.update domain_name=value, domain_entry=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lightsail",
        operation="update_domain_entry",
        op_kwargs={"domainName": domain_name, "domainEntry": domain_entry},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def add(
    hub,
    ctx,
    application_name: str,
    vpc_configuration: Dict,
    current_application_version_id: int = None,
    conditional_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Adds a Virtual Private Cloud (VPC) configuration to the application. Applications can use VPCs to store and access resources securely. Note the following about VPC configurations for Kinesis Data Analytics applications:   VPC configurations are not supported for SQL applications.   When a VPC is added to a Kinesis Data Analytics application, the application can no longer be accessed from the Internet directly. To enable Internet access to the application, add an Internet gateway to your VPC.

    Args:
        application_name(str): The name of an existing application.
        current_application_version_id(int, optional): The version of the application to which you want to add the VPC configuration. You must provide the CurrentApplicationVersionId or the ConditionalToken. You can use the DescribeApplication operation to get the current application version. If the version specified is not the current version, the ConcurrentModificationException is returned. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.
        vpc_configuration(Dict): Description of the VPC to add to the application.
        conditional_token(str, optional): A value you use to implement strong concurrency for application updates. You must provide the ApplicationVersionID or the ConditionalToken. You get the application's current ConditionalToken using DescribeApplication. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.vpc_configuration.add(
                ctx, application_name=value, vpc_configuration=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.vpc_configuration.add application_name=value, vpc_configuration=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="add_application_vpc_configuration",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "VpcConfiguration": vpc_configuration,
            "ConditionalToken": conditional_token,
        },
    )


async def delete(
    hub,
    ctx,
    application_name: str,
    vpc_configuration_id: str,
    current_application_version_id: int = None,
    conditional_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Removes a VPC configuration from a Kinesis Data Analytics application.

    Args:
        application_name(str): The name of an existing application.
        current_application_version_id(int, optional): The current application version ID. You must provide the CurrentApplicationVersionId or the ConditionalToken. You can retrieve the application version ID using DescribeApplication. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.
        vpc_configuration_id(str): The ID of the VPC configuration to delete.
        conditional_token(str, optional): A value you use to implement strong concurrency for application updates. You must provide the CurrentApplicationVersionId or the ConditionalToken. You get the application's current ConditionalToken using DescribeApplication. For better concurrency support, use the ConditionalToken parameter instead of CurrentApplicationVersionId. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kinesisanalyticsv2.application.vpc_configuration.delete(
                ctx, application_name=value, vpc_configuration_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kinesisanalyticsv2.application.vpc_configuration.delete application_name=value, vpc_configuration_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kinesisanalyticsv2",
        operation="delete_application_vpc_configuration",
        op_kwargs={
            "ApplicationName": application_name,
            "CurrentApplicationVersionId": current_application_version_id,
            "VpcConfigurationId": vpc_configuration_id,
            "ConditionalToken": conditional_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def describe(hub, ctx, workteam_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a work team provided by a vendor. It returns details about the subscription with a vendor in the Amazon Web Services Marketplace.

    Args:
        workteam_arn(str): The Amazon Resource Name (ARN) of the subscribed work team to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.subscribed_workteam.describe(ctx, workteam_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.subscribed_workteam.describe workteam_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="describe_subscribed_workteam",
        op_kwargs={"WorkteamArn": workteam_arn},
    )


async def list_all(
    hub, ctx, name_contains: str = None, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets a list of the work teams that you are subscribed to in the Amazon Web Services Marketplace. The list may be empty if no work team satisfies the filter specified in the NameContains parameter.

    Args:
        name_contains(str, optional): A string in the work team name. This filter returns only work teams whose name contains the specified string. Defaults to None.
        next_token(str, optional): If the result of the previous ListSubscribedWorkteams request was truncated, the response includes a NextToken. To retrieve the next set of labeling jobs, use the token in the next request. Defaults to None.
        max_results(int, optional): The maximum number of work teams to return in each page of the response. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.subscribed_workteam.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.subscribed_workteam.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_subscribed_workteams",
        op_kwargs={
            "NameContains": name_contains,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def activate(hub, ctx, anomaly_detector_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Activates an anomaly detector.

    Args:
        anomaly_detector_arn(str): The ARN of the anomaly detector.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.anomaly.detector.activate(
                ctx, anomaly_detector_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.anomaly.detector.activate anomaly_detector_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="activate_anomaly_detector",
        op_kwargs={"AnomalyDetectorArn": anomaly_detector_arn},
    )


async def create(
    hub,
    ctx,
    anomaly_detector_name: str,
    anomaly_detector_config: Dict,
    anomaly_detector_description: str = None,
    kms_key_arn: str = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates an anomaly detector.

    Args:
        anomaly_detector_name(str): The name of the detector.
        anomaly_detector_description(str, optional): A description of the detector. Defaults to None.
        anomaly_detector_config(Dict): Contains information about the configuration of the anomaly detector.
        kms_key_arn(str, optional): The ARN of the KMS key to use to encrypt your data. Defaults to None.
        tags(Dict, optional): A list of tags to apply to the anomaly detector. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.anomaly.detector.create(
                ctx, anomaly_detector_name=value, anomaly_detector_config=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.anomaly.detector.create anomaly_detector_name=value, anomaly_detector_config=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="create_anomaly_detector",
        op_kwargs={
            "AnomalyDetectorName": anomaly_detector_name,
            "AnomalyDetectorDescription": anomaly_detector_description,
            "AnomalyDetectorConfig": anomaly_detector_config,
            "KmsKeyArn": kms_key_arn,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, anomaly_detector_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a detector. Deleting an anomaly detector will delete all of its corresponding resources including any configured datasets and alerts.

    Args:
        anomaly_detector_arn(str): The ARN of the detector to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.anomaly.detector.delete(
                ctx, anomaly_detector_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.anomaly.detector.delete anomaly_detector_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="delete_anomaly_detector",
        op_kwargs={"AnomalyDetectorArn": anomaly_detector_arn},
    )


async def describe(hub, ctx, anomaly_detector_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Describes a detector. Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.

    Args:
        anomaly_detector_arn(str): The ARN of the detector to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.anomaly.detector.describe(
                ctx, anomaly_detector_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.anomaly.detector.describe anomaly_detector_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="describe_anomaly_detector",
        op_kwargs={"AnomalyDetectorArn": anomaly_detector_arn},
    )


async def list_all(hub, ctx, max_results: int = None, next_token: str = None) -> Dict:
    r"""
    **Autogenerated function**

    Lists the detectors in the current AWS Region. Amazon Lookout for Metrics API actions are eventually consistent. If you do a read operation on a resource immediately after creating or modifying it, use retries to allow time for the write operation to complete.

    Args:
        max_results(int, optional): The maximum number of results to return. Defaults to None.
        next_token(str, optional): If the result of the previous request was truncated, the response includes a NextToken. To retrieve the next set of results, use the token in the next request. Tokens expire after 24 hours. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.anomaly.detector.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.anomaly.detector.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="list_anomaly_detectors",
        op_kwargs={"MaxResults": max_results, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    anomaly_detector_arn: str,
    kms_key_arn: str = None,
    anomaly_detector_description: str = None,
    anomaly_detector_config: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates a detector. After activation, you can only change a detector's ingestion delay and description.

    Args:
        anomaly_detector_arn(str): The ARN of the detector to update.
        kms_key_arn(str, optional): The Amazon Resource Name (ARN) of an AWS KMS encryption key. Defaults to None.
        anomaly_detector_description(str, optional): The updated detector description. Defaults to None.
        anomaly_detector_config(Dict, optional): Contains information about the configuration to which the detector will be updated. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.lookoutmetric.anomaly.detector.update(
                ctx, anomaly_detector_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.lookoutmetric.anomaly.detector.update anomaly_detector_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="lookoutmetrics",
        operation="update_anomaly_detector",
        op_kwargs={
            "AnomalyDetectorArn": anomaly_detector_arn,
            "KmsKeyArn": kms_key_arn,
            "AnomalyDetectorDescription": anomaly_detector_description,
            "AnomalyDetectorConfig": anomaly_detector_config,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def describe(hub, ctx, association_arn: str) -> Dict:
    r"""
    **Autogenerated function**

     Returns a  RepositoryAssociation  object that contains information about the requested repository association.

    Args:
        association_arn(str):  The Amazon Resource Name (ARN) of the  RepositoryAssociation  object. You can retrieve this ARN by calling  ListRepositoryAssociations . .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.repository.association.describe(
                ctx, association_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.repository.association.describe association_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="describe_repository_association",
        op_kwargs={"AssociationArn": association_arn},
    )


async def list_all(
    hub,
    ctx,
    provider_types: List = None,
    states: List = None,
    names: List = None,
    owners: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

     Returns a list of  RepositoryAssociationSummary  objects that contain summary information about a repository association. You can filter the returned list by  ProviderType ,  Name ,  State , and  Owner .

    Args:
        provider_types(List, optional): List of provider types to use as a filter. Defaults to None.
        states(List, optional): List of repository association states to use as a filter. The valid repository association states are:    Associated: The repository association is complete.     Associating: CodeGuru Reviewer is:     Setting up pull request notifications. This is required for pull requests to trigger a CodeGuru Reviewer review.    If your repository ProviderType is GitHub, GitHub Enterprise Server, or Bitbucket, CodeGuru Reviewer creates webhooks in your repository to trigger CodeGuru Reviewer reviews. If you delete these webhooks, reviews of code in your repository cannot be triggered.      Setting up source code access. This is required for CodeGuru Reviewer to securely clone code in your repository.       Failed: The repository failed to associate or disassociate.     Disassociating: CodeGuru Reviewer is removing the repository's pull request notifications and source code access.     Disassociated: CodeGuru Reviewer successfully disassociated the repository. You can create a new association with this repository if you want to review source code in it later. You can control access to code reviews created in an associated repository with tags after it has been disassociated. For more information, see Using tags to control access to associated repositories in the Amazon CodeGuru Reviewer User Guide.   . Defaults to None.
        names(List, optional): List of repository names to use as a filter. Defaults to None.
        owners(List, optional): List of owners to use as a filter. For AWS CodeCommit, it is the name of the CodeCommit account that was used to associate the repository. For other repository source providers, such as Bitbucket and GitHub Enterprise Server, this is name of the account that was used to associate the repository. . Defaults to None.
        max_results(int, optional): The maximum number of repository association results returned by ListRepositoryAssociations in paginated output. When this parameter is used, ListRepositoryAssociations only returns maxResults results in a single page with a nextToken response element. The remaining results of the initial request can be seen by sending another ListRepositoryAssociations request with the returned nextToken value. This value can be between 1 and 100. If this parameter is not used, ListRepositoryAssociations returns up to 100 results and a nextToken value if applicable. . Defaults to None.
        next_token(str, optional): The nextToken value returned from a previous paginated ListRepositoryAssociations request where maxResults was used and the results exceeded the value of that parameter. Pagination continues from the end of the previous results that returned the nextToken value.   Treat this token as an opaque identifier that is only used to retrieve the next items in a list and not for other programmatic purposes. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.codeguru_reviewer.repository.association.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.codeguru_reviewer.repository.association.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="codeguru-reviewer",
        operation="list_repository_associations",
        op_kwargs={
            "ProviderTypes": provider_types,
            "States": states,
            "Names": names,
            "Owners": owners,
            "MaxResults": max_results,
            "NextToken": next_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def count(hub, ctx, domain: str, task_list: Dict) -> Dict:
    r"""
    **Autogenerated function**

    Returns the estimated number of activity tasks in the specified task list. The count returned is an approximation and isn't guaranteed to be exact. If you specify a task list that no activity task was ever scheduled in then 0 is returned.  Access Control  You can use IAM policies to control this action's access to Amazon SWF resources as follows:   Use a Resource element with the domain name to limit the action to only specified domains.   Use an Action element to allow or deny permission to call this action.   Constrain the taskList.name parameter by using a Condition element with the swf:taskList.name key to allow the action to access only certain task lists.   If the caller doesn't have sufficient permissions to invoke the action, or the parameter values fall outside the specified constraints, the action fails. The associated event attribute's cause parameter is set to OPERATION_NOT_PERMITTED. For details and example IAM policies, see Using IAM to Manage Access to Amazon SWF Workflows in the Amazon SWF Developer Guide.

    Args:
        domain(str): The name of the domain that contains the task list.
        task_list(Dict): The name of the task list.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.swf.pending.activity_task.count(
                ctx, domain=value, task_list=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.swf.pending.activity_task.count domain=value, task_list=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="swf",
        operation="count_pending_activity_tasks",
        op_kwargs={"domain": domain, "taskList": task_list},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get_all(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Gets the License Manager settings for the current Region.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.service_setting.get_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.service_setting.get_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="get_service_settings",
        op_kwargs={},
    )


async def update_multiple(
    hub,
    ctx,
    s3_bucket_arn: str = None,
    sns_topic_arn: str = None,
    organization_configuration: Dict = None,
    enable_cross_accounts_discovery: bool = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates License Manager settings for the current Region.

    Args:
        s3_bucket_arn(str, optional): Amazon Resource Name (ARN) of the Amazon S3 bucket where the License Manager information is stored. Defaults to None.
        sns_topic_arn(str, optional): Amazon Resource Name (ARN) of the Amazon SNS topic used for License Manager alerts. Defaults to None.
        organization_configuration(Dict, optional): Enables integration with AWS Organizations for cross-account discovery. Defaults to None.
        enable_cross_accounts_discovery(bool, optional): Activates cross-account discovery. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.service_setting.update_multiple(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.service_setting.update_multiple
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="update_service_settings",
        op_kwargs={
            "S3BucketArn": s3_bucket_arn,
            "SnsTopicArn": sns_topic_arn,
            "OrganizationConfiguration": organization_configuration,
            "EnableCrossAccountsDiscovery": enable_cross_accounts_discovery,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def get_all(
    hub,
    ctx,
    time_period: Dict,
    granularity: str,
    filter_: Dict,
    metrics: List = None,
    group_by: List = None,
    next_page_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves cost and usage metrics with resources for your account. You can specify which cost and usage-related metric, such as BlendedCosts or UsageQuantity, that you want the request to return. You can also filter and group your data by various dimensions, such as SERVICE or AZ, in a specific time range. For a complete list of valid dimensions, see the GetDimensionValues operation. Management account in an organization in AWS Organizations have access to all member accounts. This API is currently available for the Amazon Elastic Compute Cloud – Compute service only.  This is an opt-in only feature. You can enable this feature from the Cost Explorer Settings page. For information on how to access the Settings page, see Controlling Access for Cost Explorer in the AWS Billing and Cost Management User Guide.

    Args:
        time_period(Dict): Sets the start and end dates for retrieving Amazon Web Services costs. The range must be within the last 14 days (the start date cannot be earlier than 14 days ago). The start date is inclusive, but the end date is exclusive. For example, if start is 2017-01-01 and end is 2017-05-01, then the cost and usage data is retrieved from 2017-01-01 up to and including 2017-04-30 but not including 2017-05-01.
        granularity(str): Sets the AWS cost granularity to MONTHLY, DAILY, or HOURLY. If Granularity isn't set, the response object doesn't include the Granularity, MONTHLY, DAILY, or HOURLY. .
        filter_(Dict): Filters Amazon Web Services costs by different dimensions. For example, you can specify SERVICE and LINKED_ACCOUNT and get the costs that are associated with that account's usage of that service. You can nest Expression objects to define any combination of dimension filters. For more information, see Expression.  The GetCostAndUsageWithResources operation requires that you either group by or filter by a ResourceId. It requires the Expression "SERVICE = Amazon Elastic Compute Cloud - Compute" in the filter.
        metrics(List, optional): Which metrics are returned in the query. For more information about blended and unblended rates, see Why does the "blended" annotation appear on some line items in my bill?.  Valid values are AmortizedCost, BlendedCost, NetAmortizedCost, NetUnblendedCost, NormalizedUsageAmount, UnblendedCost, and UsageQuantity.   If you return the UsageQuantity metric, the service aggregates all usage numbers without taking the units into account. For example, if you aggregate usageQuantity across all of Amazon EC2, the results aren't meaningful because Amazon EC2 compute hours and data transfer are measured in different units (for example, hours vs. GB). To get more meaningful UsageQuantity metrics, filter by UsageType or UsageTypeGroups.    Metrics is required for GetCostAndUsageWithResources requests. Defaults to None.
        group_by(List, optional): You can group Amazon Web Services costs using up to two different groups: DIMENSION, TAG, COST_CATEGORY. Defaults to None.
        next_page_token(str, optional): The token to retrieve the next set of results. AWS provides the token when the response from a previous call has more results than the maximum page size. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.ce.cost.and_usage.with_resource.get_all(
                ctx, time_period=value, granularity=value, filter_=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.ce.cost.and_usage.with_resource.get_all time_period=value, granularity=value, filter_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="ce",
        operation="get_cost_and_usage_with_resources",
        op_kwargs={
            "TimePeriod": time_period,
            "Granularity": granularity,
            "Filter": filter_,
            "Metrics": metrics,
            "GroupBy": group_by,
            "NextPageToken": next_page_token,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def re(
    hub,
    ctx,
    ciphertext_blob: bytes,
    destination_key_id: str,
    source_encryption_context: Dict = None,
    source_key_id: str = None,
    destination_encryption_context: Dict = None,
    source_encryption_algorithm: str = None,
    destination_encryption_algorithm: str = None,
    grant_tokens: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Decrypts ciphertext and then reencrypts it entirely within AWS KMS. You can use this operation to change the customer master key (CMK) under which data is encrypted, such as when you manually rotate a CMK or change the CMK that protects a ciphertext. You can also use it to reencrypt ciphertext under the same CMK, such as to change the encryption context of a ciphertext. The ReEncrypt operation can decrypt ciphertext that was encrypted by using an AWS KMS CMK in an AWS KMS operation, such as Encrypt or GenerateDataKey. It can also decrypt ciphertext that was encrypted by using the public key of an asymmetric CMK outside of AWS KMS. However, it cannot decrypt ciphertext produced by other libraries, such as the AWS Encryption SDK or Amazon S3 client-side encryption. These libraries return a ciphertext format that is incompatible with AWS KMS. When you use the ReEncrypt operation, you need to provide information for the decrypt operation and the subsequent encrypt operation.   If your ciphertext was encrypted under an asymmetric CMK, you must use the SourceKeyId parameter to identify the CMK that encrypted the ciphertext. You must also supply the encryption algorithm that was used. This information is required to decrypt the data.   If your ciphertext was encrypted under a symmetric CMK, the SourceKeyId parameter is optional. AWS KMS can get this information from metadata that it adds to the symmetric ciphertext blob. This feature adds durability to your implementation by ensuring that authorized users can decrypt ciphertext decades after it was encrypted, even if they've lost track of the CMK ID. However, specifying the source CMK is always recommended as a best practice. When you use the SourceKeyId parameter to specify a CMK, AWS KMS uses only the CMK you specify. If the ciphertext was encrypted under a different CMK, the ReEncrypt operation fails. This practice ensures that you use the CMK that you intend.   To reencrypt the data, you must use the DestinationKeyId parameter specify the CMK that re-encrypts the data after it is decrypted. You can select a symmetric or asymmetric CMK. If the destination CMK is an asymmetric CMK, you must also provide the encryption algorithm. The algorithm that you choose must be compatible with the CMK.  When you use an asymmetric CMK to encrypt or reencrypt data, be sure to record the CMK and encryption algorithm that you choose. You will be required to provide the same CMK and encryption algorithm when you decrypt the data. If the CMK and algorithm do not match the values used to encrypt the data, the decrypt operation fails. You are not required to supply the CMK ID and encryption algorithm when you decrypt with symmetric CMKs because AWS KMS stores this information in the ciphertext blob. AWS KMS cannot store metadata in ciphertext generated with asymmetric keys. The standard format for asymmetric key ciphertext does not include configurable fields.    The CMK that you use for this operation must be in a compatible key state. For details, see Key state: Effect on your CMK in the AWS Key Management Service Developer Guide.  Cross-account use: Yes. The source CMK and destination CMK can be in different AWS accounts. Either or both CMKs can be in a different account than the caller.  Required permissions:    kms:ReEncryptFrom permission on the source CMK (key policy)    kms:ReEncryptTo permission on the destination CMK (key policy)   To permit reencryption from or to a CMK, include the "kms:ReEncrypt*" permission in your key policy. This permission is automatically included in the key policy when you use the console to create a CMK. But you must include it manually when you create a CMK programmatically or when you use the PutKeyPolicy operation to set a key policy.  Related operations:     Decrypt     Encrypt     GenerateDataKey     GenerateDataKeyPair

    Args:
        ciphertext_blob(bytes): Ciphertext of the data to reencrypt.
        source_encryption_context(Dict, optional): Specifies the encryption context to use to decrypt the ciphertext. Enter the same encryption context that was used to encrypt the ciphertext. An encryption context is a collection of non-secret key-value pairs that represents additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is optional when encrypting with a symmetric CMK, but it is highly recommended. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. Defaults to None.
        source_key_id(str, optional): Specifies the customer master key (CMK) that AWS KMS will use to decrypt the ciphertext before it is re-encrypted. Enter a key ID of the CMK that was used to encrypt the ciphertext. This parameter is required only when the ciphertext was encrypted under an asymmetric CMK. If you used a symmetric CMK, AWS KMS can get the CMK from metadata that it adds to the symmetric ciphertext blob. However, it is always recommended as a best practice. This practice ensures that you use the CMK that you intend. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases. Defaults to None.
        destination_key_id(str): A unique identifier for the CMK that is used to reencrypt the data. Specify a symmetric or asymmetric CMK with a KeyUsage value of ENCRYPT_DECRYPT. To find the KeyUsage value of a CMK, use the DescribeKey operation. To specify a CMK, use its key ID, key ARN, alias name, or alias ARN. When using an alias name, prefix it with "alias/". To specify a CMK in a different AWS account, you must use the key ARN or alias ARN. For example:   Key ID: 1234abcd-12ab-34cd-56ef-1234567890ab    Key ARN: arn:aws:kms:us-east-2:111122223333:key/1234abcd-12ab-34cd-56ef-1234567890ab    Alias name: alias/ExampleAlias    Alias ARN: arn:aws:kms:us-east-2:111122223333:alias/ExampleAlias    To get the key ID and key ARN for a CMK, use ListKeys or DescribeKey. To get the alias name and alias ARN, use ListAliases.
        destination_encryption_context(Dict, optional): Specifies that encryption context to use when the reencrypting the data. A destination encryption context is valid only when the destination CMK is a symmetric CMK. The standard ciphertext format for asymmetric CMKs does not include fields for metadata. An encryption context is a collection of non-secret key-value pairs that represents additional authenticated data. When you use an encryption context to encrypt data, you must specify the same (an exact case-sensitive match) encryption context to decrypt the data. An encryption context is optional when encrypting with a symmetric CMK, but it is highly recommended. For more information, see Encryption Context in the AWS Key Management Service Developer Guide. Defaults to None.
        source_encryption_algorithm(str, optional): Specifies the encryption algorithm that AWS KMS will use to decrypt the ciphertext before it is reencrypted. The default value, SYMMETRIC_DEFAULT, represents the algorithm used for symmetric CMKs. Specify the same algorithm that was used to encrypt the ciphertext. If you specify a different algorithm, the decrypt attempt fails. This parameter is required only when the ciphertext was encrypted under an asymmetric CMK. Defaults to None.
        destination_encryption_algorithm(str, optional): Specifies the encryption algorithm that AWS KMS will use to reecrypt the data after it has decrypted it. The default value, SYMMETRIC_DEFAULT, represents the encryption algorithm used for symmetric CMKs. This parameter is required only when the destination CMK is an asymmetric CMK. Defaults to None.
        grant_tokens(List, optional): A list of grant tokens. Use a grant token when your permission to call this operation comes from a new grant that has not yet achieved eventual consistency. For more information, see Grant token in the AWS Key Management Service Developer Guide. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.kms.encrypt.re(
                ctx, ciphertext_blob=value, destination_key_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.kms.encrypt.re ciphertext_blob=value, destination_key_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="kms",
        operation="re_encrypt",
        op_kwargs={
            "CiphertextBlob": ciphertext_blob,
            "SourceEncryptionContext": source_encryption_context,
            "SourceKeyId": source_key_id,
            "DestinationKeyId": destination_key_id,
            "DestinationEncryptionContext": destination_encryption_context,
            "SourceEncryptionAlgorithm": source_encryption_algorithm,
            "DestinationEncryptionAlgorithm": destination_encryption_algorithm,
            "GrantTokens": grant_tokens,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def cancel(hub, ctx, environment_name: str) -> Dict:
    r"""
    **Autogenerated function**

    Attempts to cancel an environment deployment on an UpdateEnvironment action, if the deployment is IN_PROGRESS. For more information, see Update an environment in the AWS Proton Administrator guide. The following list includes potential cancellation scenarios.   If the cancellation attempt succeeds, the resulting deployment state is CANCELLED.   If the cancellation attempt fails, the resulting deployment state is FAILED.   If the current UpdateEnvironment action succeeds before the cancellation attempt starts, the resulting deployment state is SUCCEEDED and the cancellation attempt has no effect.

    Args:
        environment_name(str): The name of the environment with the deployment to cancel.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.proton.environment.deployment.cancel(
                ctx, environment_name=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.proton.environment.deployment.cancel environment_name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="proton",
        operation="cancel_environment_deployment",
        op_kwargs={"environmentName": environment_name},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def cancel(hub, ctx, id_: str, virtual_cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Cancels a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.

    Args:
        id_(str): The ID of the job run to cancel.
        virtual_cluster_id(str): The ID of the virtual cluster for which the job run will be canceled.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.job_run.cancel(
                ctx, id_=value, virtual_cluster_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.job_run.cancel id_=value, virtual_cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="cancel_job_run",
        op_kwargs={"id": id_, "virtualClusterId": virtual_cluster_id},
    )


async def describe(hub, ctx, id_: str, virtual_cluster_id: str) -> Dict:
    r"""
    **Autogenerated function**

    Displays detailed information about a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.

    Args:
        id_(str): The ID of the job run request. .
        virtual_cluster_id(str): The ID of the virtual cluster for which the job run is submitted.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.job_run.describe(
                ctx, id_=value, virtual_cluster_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.job_run.describe id_=value, virtual_cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="describe_job_run",
        op_kwargs={"id": id_, "virtualClusterId": virtual_cluster_id},
    )


async def list_all(
    hub,
    ctx,
    virtual_cluster_id: str,
    created_before: str = None,
    created_after: str = None,
    name: str = None,
    states: List = None,
    max_results: int = None,
    next_token: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Lists job runs based on a set of parameters. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.

    Args:
        virtual_cluster_id(str): The ID of the virtual cluster for which to list the job run. .
        created_before(str, optional): The date and time before which the job runs were submitted. Defaults to None.
        created_after(str, optional): The date and time after which the job runs were submitted. Defaults to None.
        name(str, optional): The name of the job run. Defaults to None.
        states(List, optional): The states of the job run. Defaults to None.
        max_results(int, optional): The maximum number of job runs that can be listed. Defaults to None.
        next_token(str, optional): The token for the next set of job runs to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.job_run.list_all(ctx, virtual_cluster_id=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.job_run.list_all virtual_cluster_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="list_job_runs",
        op_kwargs={
            "virtualClusterId": virtual_cluster_id,
            "createdBefore": created_before,
            "createdAfter": created_after,
            "name": name,
            "states": states,
            "maxResults": max_results,
            "nextToken": next_token,
        },
    )


async def start(
    hub,
    ctx,
    virtual_cluster_id: str,
    client_token: str,
    execution_role_arn: str,
    release_label: str,
    job_driver: Dict,
    name: str = None,
    configuration_overrides: Dict = None,
    tags: Dict = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Starts a job run. A job run is a unit of work, such as a Spark jar, PySpark script, or SparkSQL query, that you submit to Amazon EMR on EKS.

    Args:
        name(str, optional): The name of the job run. Defaults to None.
        virtual_cluster_id(str): The virtual cluster ID for which the job run request is submitted.
        client_token(str): The client idempotency token of the job run request. .
        execution_role_arn(str): The execution role ARN for the job run.
        release_label(str): The Amazon EMR release version to use for the job run.
        job_driver(Dict): The job driver for the job run.
        configuration_overrides(Dict, optional): The configuration overrides for the job run. Defaults to None.
        tags(Dict, optional): The tags assigned to job runs. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.emr_container.job_run.start(
                ctx,
                virtual_cluster_id=value,
                client_token=value,
                execution_role_arn=value,
                release_label=value,
                job_driver=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.emr_container.job_run.start virtual_cluster_id=value, client_token=value, execution_role_arn=value, release_label=value, job_driver=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="emr-containers",
        operation="start_job_run",
        op_kwargs={
            "name": name,
            "virtualClusterId": virtual_cluster_id,
            "clientToken": client_token,
            "executionRoleArn": execution_role_arn,
            "releaseLabel": release_label,
            "jobDriver": job_driver,
            "configurationOverrides": configuration_overrides,
            "tags": tags,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def extend(
    hub, ctx, license_consumption_token: str, dry_run: bool = None
) -> Dict:
    r"""
    **Autogenerated function**

    Extends the expiration date for license consumption.

    Args:
        license_consumption_token(str): License consumption token.
        dry_run(bool, optional): Checks whether you have the required permissions for the action, without actually making the request. Provides an error response if you do not have the required permissions. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.license_manager.license_.consumption.extend(
                ctx, license_consumption_token=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.license_manager.license_.consumption.extend license_consumption_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="license-manager",
        operation="extend_license_consumption",
        op_kwargs={
            "LicenseConsumptionToken": license_consumption_token,
            "DryRun": dry_run,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def get(hub, ctx) -> Dict:
    r"""
    **Autogenerated function**

    Returns details about the IAM user or role whose credentials are used to call the operation.  No permissions are required to perform this operation. If an administrator adds a policy to your IAM user or role that explicitly denies access to the sts:GetCallerIdentity action, you can still perform this operation. Permissions are not required because the same information is returned when an IAM user or role is denied access. To view an example response, see I Am Not Authorized to Perform: iam:DeleteVirtualMFADevice in the IAM User Guide.


    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sts.caller_identity.get(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sts.caller_identity.get
    """
    return await hub.tool.aws.client.exec(
        ctx, service_name="sts", operation="get_caller_identity", op_kwargs={}
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    name: str,
    timeout_in_seconds: int = None,
    player_latency_policies: List = None,
    destinations: List = None,
    filter_configuration: Dict = None,
    priority_configuration: Dict = None,
    custom_event_data: str = None,
    notification_target: str = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a placement queue that processes requests for new game sessions. A queue uses FleetIQ algorithms to determine the best placement locations and find an available game server there, then prompts the game server process to start a new game session.  A game session queue is configured with a set of destinations (GameLift fleets or aliases), which determine the locations where the queue can place new game sessions. These destinations can span multiple fleet types (Spot and On-Demand), instance types, and AWS Regions. If the queue includes multi-location fleets, the queue is able to place game sessions in all of a fleet's remote locations. You can opt to filter out individual locations if needed. The queue configuration also determines how FleetIQ selects the best available placement for a new game session. Before searching for an available game server, FleetIQ first prioritizes the queue's destinations and locations, with the best placement locations on top. You can set up the queue to use the FleetIQ default prioritization or provide an alternate set of priorities. To create a new queue, provide a name, timeout value, and a list of destinations. Optionally, specify a sort configuration and/or a filter, and define a set of latency cap policies. You can also include the ARN for an Amazon Simple Notification Service (SNS) topic to receive notifications of game session placement activity. Notifications using SNS or CloudWatch events is the preferred way to track placement activity. If successful, a new GameSessionQueue object is returned with an assigned queue ARN. New game session requests, which are submitted to the queue with StartGameSessionPlacement or StartMatchmaking, reference a queue's name or ARN.   Learn more    Design a game session queue    Create a game session queue   Related actions   CreateGameSessionQueue | DescribeGameSessionQueues | UpdateGameSessionQueue | DeleteGameSessionQueue | All APIs by task

    Args:
        name(str): A descriptive label that is associated with game session queue. Queue names must be unique within each Region.
        timeout_in_seconds(int, optional): The maximum time, in seconds, that a new game session placement request remains in the queue. When a request exceeds this time, the game session placement changes to a TIMED_OUT status. Defaults to None.
        player_latency_policies(List, optional): A set of policies that act as a sliding cap on player latency. FleetIQ works to deliver low latency for most players in a game session. These policies ensure that no individual player can be placed into a game with unreasonably high latency. Use multiple policies to gradually relax latency requirements a step at a time. Multiple policies are applied based on their maximum allowed latency, starting with the lowest value. Defaults to None.
        destinations(List, optional): A list of fleets and/or fleet aliases that can be used to fulfill game session placement requests in the queue. Destinations are identified by either a fleet ARN or a fleet alias ARN, and are listed in order of placement preference. Defaults to None.
        filter_configuration(Dict, optional): A list of locations where a queue is allowed to place new game sessions. Locations are specified in the form of AWS Region codes, such as us-west-2. If this parameter is not set, game sessions can be placed in any queue location. . Defaults to None.
        priority_configuration(Dict, optional): Custom settings to use when prioritizing destinations and locations for game session placements. This configuration replaces the FleetIQ default prioritization process. Priority types that are not explicitly named will be automatically applied at the end of the prioritization process. . Defaults to None.
        custom_event_data(str, optional):  Information to be added to all events that are related to this game session queue. . Defaults to None.
        notification_target(str, optional): An SNS topic ARN that is set up to receive game session placement notifications. See  Setting up notifications for game session placement. Defaults to None.
        tags(List, optional): A list of labels to assign to the new game session queue resource. Tags are developer-defined key-value pairs. Tagging AWS resources are useful for resource management, access management and cost allocation. For more information, see  Tagging AWS Resources in the AWS General Reference. Once the resource is created, you can use TagResource, UntagResource, and ListTagsForResource to add, remove, and view tags. The maximum tag limit may be lower than stated. See the AWS General Reference for actual tagging limits. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.queue.create(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.queue.create name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="create_game_session_queue",
        op_kwargs={
            "Name": name,
            "TimeoutInSeconds": timeout_in_seconds,
            "PlayerLatencyPolicies": player_latency_policies,
            "Destinations": destinations,
            "FilterConfiguration": filter_configuration,
            "PriorityConfiguration": priority_configuration,
            "CustomEventData": custom_event_data,
            "NotificationTarget": notification_target,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, name: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a game session queue. Once a queue is successfully deleted, unfulfilled StartGameSessionPlacement requests that reference the queue will fail. To delete a queue, specify the queue name.  Learn more    Using Multi-Region Queues   Related actions   CreateGameSessionQueue | DescribeGameSessionQueues | UpdateGameSessionQueue | DeleteGameSessionQueue | All APIs by task

    Args:
        name(str): A descriptive label that is associated with game session queue. Queue names must be unique within each Region. You can use either the queue ID or ARN value. .

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.queue.delete(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.queue.delete name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="delete_game_session_queue",
        op_kwargs={"Name": name},
    )


async def describe_all(
    hub, ctx, names: List = None, limit: int = None, next_token: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Retrieves the properties for one or more game session queues. When requesting multiple queues, use the pagination parameters to retrieve results as a set of sequential pages. If successful, a GameSessionQueue object is returned for each requested queue. When specifying a list of queues, objects are returned only for queues that currently exist in the Region.  Learn more    View Your Queues   Related actions   CreateGameSessionQueue | DescribeGameSessionQueues | UpdateGameSessionQueue | DeleteGameSessionQueue | All APIs by task

    Args:
        names(List, optional): A list of queue names to retrieve information for. You can use either the queue ID or ARN value. To request settings for all queues, leave this parameter empty. . Defaults to None.
        limit(int, optional): The maximum number of results to return. Use this parameter with NextToken to get results as a set of sequential pages. You can request up to 50 results. Defaults to None.
        next_token(str, optional): A token that indicates the start of the next sequential page of results. Use the token that is returned with a previous call to this operation. To start at the beginning of the result set, do not specify a value. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.queue.describe_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.queue.describe_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="describe_game_session_queues",
        op_kwargs={"Names": names, "Limit": limit, "NextToken": next_token},
    )


async def update(
    hub,
    ctx,
    name: str,
    timeout_in_seconds: int = None,
    player_latency_policies: List = None,
    destinations: List = None,
    filter_configuration: Dict = None,
    priority_configuration: Dict = None,
    custom_event_data: str = None,
    notification_target: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the configuration of a game session queue, which determines how the queue processes new game session requests. To update settings, specify the queue name to be updated and provide the new settings. When updating destinations, provide a complete list of destinations.   Learn more    Using Multi-Region Queues   Related actions   CreateGameSessionQueue | DescribeGameSessionQueues | UpdateGameSessionQueue | DeleteGameSessionQueue | All APIs by task

    Args:
        name(str): A descriptive label that is associated with game session queue. Queue names must be unique within each Region. You can use either the queue ID or ARN value. .
        timeout_in_seconds(int, optional): The maximum time, in seconds, that a new game session placement request remains in the queue. When a request exceeds this time, the game session placement changes to a TIMED_OUT status. Defaults to None.
        player_latency_policies(List, optional): A set of policies that act as a sliding cap on player latency. FleetIQ works to deliver low latency for most players in a game session. These policies ensure that no individual player can be placed into a game with unreasonably high latency. Use multiple policies to gradually relax latency requirements a step at a time. Multiple policies are applied based on their maximum allowed latency, starting with the lowest value. When updating policies, provide a complete collection of policies. Defaults to None.
        destinations(List, optional): A list of fleets and/or fleet aliases that can be used to fulfill game session placement requests in the queue. Destinations are identified by either a fleet ARN or a fleet alias ARN, and are listed in order of placement preference. When updating this list, provide a complete list of destinations. Defaults to None.
        filter_configuration(Dict, optional): A list of locations where a queue is allowed to place new game sessions. Locations are specified in the form of AWS Region codes, such as us-west-2. If this parameter is not set, game sessions can be placed in any queue location. To remove an existing filter configuration, pass in an empty set. Defaults to None.
        priority_configuration(Dict, optional): Custom settings to use when prioritizing destinations and locations for game session placements. This configuration replaces the FleetIQ default prioritization process. Priority types that are not explicitly named will be automatically applied at the end of the prioritization process. To remove an existing priority configuration, pass in an empty set. Defaults to None.
        custom_event_data(str, optional):  Information to be added to all events that are related to this game session queue. . Defaults to None.
        notification_target(str, optional): An SNS topic ARN that is set up to receive game session placement notifications. See  Setting up notifications for game session placement. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.gamelift.game.session.queue.update(ctx, name=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.gamelift.game.session.queue.update name=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="gamelift",
        operation="update_game_session_queue",
        op_kwargs={
            "Name": name,
            "TimeoutInSeconds": timeout_in_seconds,
            "PlayerLatencyPolicies": player_latency_policies,
            "Destinations": destinations,
            "FilterConfiguration": filter_configuration,
            "PriorityConfiguration": priority_configuration,
            "CustomEventData": custom_event_data,
            "NotificationTarget": notification_target,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def delete(
    hub, ctx, channel_arn: str, message_id: str, chime_bearer: str = None
) -> None:
    r"""
    **Autogenerated function**

    Deletes a channel message. Only admins can perform this action. Deletion makes messages inaccessible immediately. A background process deletes any revisions created by UpdateChannelMessage.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel.
        message_id(str): The ID of the message being deleted.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.message.delete(
                ctx, channel_arn=value, message_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.message.delete channel_arn=value, message_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="delete_channel_message",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MessageId": message_id,
            "ChimeBearer": chime_bearer,
        },
    )


async def get(
    hub, ctx, channel_arn: str, message_id: str, chime_bearer: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Gets the full details of a channel message.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel.
        message_id(str): The ID of the message.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.message.get(
                ctx, channel_arn=value, message_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.message.get channel_arn=value, message_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="get_channel_message",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MessageId": message_id,
            "ChimeBearer": chime_bearer,
        },
    )


async def list_all(
    hub,
    ctx,
    channel_arn: str,
    sort_order: str = None,
    not_before: str = None,
    not_after: str = None,
    max_results: int = None,
    next_token: str = None,
    chime_bearer: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    List all the messages in a channel. Returns a paginated list of ChannelMessages. By default, sorted by creation timestamp in descending order.  Redacted messages appear in the results as empty, since they are only redacted, not deleted. Deleted messages do not appear in the results. This action always returns the latest version of an edited message. Also, the x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel.
        sort_order(str, optional): The order in which you want messages sorted. Default is Descending, based on time created. Defaults to None.
        not_before(str, optional): The initial or starting time stamp for your requested messages. Defaults to None.
        not_after(str, optional): The final or ending time stamp for your requested messages. Defaults to None.
        max_results(int, optional): The maximum number of messages that you want returned. Defaults to None.
        next_token(str, optional): The token passed by previous API calls until all requested messages are returned. Defaults to None.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.message.list_all(ctx, channel_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.message.list_all channel_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="list_channel_messages",
        op_kwargs={
            "ChannelArn": channel_arn,
            "SortOrder": sort_order,
            "NotBefore": not_before,
            "NotAfter": not_after,
            "MaxResults": max_results,
            "NextToken": next_token,
            "ChimeBearer": chime_bearer,
        },
    )


async def redact(
    hub, ctx, channel_arn: str, message_id: str, chime_bearer: str = None
) -> Dict:
    r"""
    **Autogenerated function**

    Redacts message content, but not metadata. The message exists in the back end, but the action returns null content, and the state shows as redacted.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel containing the messages that you want to redact.
        message_id(str): The ID of the message being redacted.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.message.redact(
                ctx, channel_arn=value, message_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.message.redact channel_arn=value, message_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="redact_channel_message",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MessageId": message_id,
            "ChimeBearer": chime_bearer,
        },
    )


async def send(
    hub,
    ctx,
    channel_arn: str,
    content: str,
    type_: str,
    persistence: str,
    client_request_token: str,
    metadata: str = None,
    chime_bearer: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Sends a message to a particular channel that the member is a part of.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header. Also, STANDARD messages can contain 4KB of data and the 1KB of metadata. CONTROL messages can contain 30 bytes of data and no metadata.

    Args:
        channel_arn(str): The ARN of the channel.
        content(str): The content of the message.
        type_(str): The type of message, STANDARD or CONTROL.
        persistence(str): Boolean that controls whether the message is persisted on the back end. Required.
        metadata(str, optional): The optional metadata for each message. Defaults to None.
        client_request_token(str): The Idempotency token for each client request.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.message.send(
                ctx,
                channel_arn=value,
                content=value,
                type_=value,
                persistence=value,
                client_request_token=value,
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.message.send channel_arn=value, content=value, type_=value, persistence=value, client_request_token=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="send_channel_message",
        op_kwargs={
            "ChannelArn": channel_arn,
            "Content": content,
            "Type": type_,
            "Persistence": persistence,
            "Metadata": metadata,
            "ClientRequestToken": client_request_token,
            "ChimeBearer": chime_bearer,
        },
    )


async def update(
    hub,
    ctx,
    channel_arn: str,
    message_id: str,
    content: str = None,
    metadata: str = None,
    chime_bearer: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the content of a message.  The x-amz-chime-bearer request header is mandatory. Use the AppInstanceUserArn of the user that makes the API call as the value in the header.

    Args:
        channel_arn(str): The ARN of the channel.
        message_id(str): The ID string of the message being updated.
        content(str, optional): The content of the message being updated. Defaults to None.
        metadata(str, optional): The metadata of the message being updated. Defaults to None.
        chime_bearer(str, optional): The AppInstanceUserArn of the user that makes the API call. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.chime.channel.message.update(
                ctx, channel_arn=value, message_id=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.chime.channel.message.update channel_arn=value, message_id=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="chime",
        operation="update_channel_message",
        op_kwargs={
            "ChannelArn": channel_arn,
            "MessageId": message_id,
            "Content": content,
            "Metadata": metadata,
            "ChimeBearer": chime_bearer,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""


async def delete(hub, ctx, endpoint_arn: str) -> None:
    r"""
    **Autogenerated function**

    Deletes the endpoint for a device and mobile app from Amazon SNS. This action is idempotent. For more information, see Using Amazon SNS Mobile Push Notifications.  When you delete an endpoint that is also subscribed to a topic, then you must also unsubscribe the endpoint from the topic.

    Args:
        endpoint_arn(str): EndpointArn of endpoint to delete.
    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sns.endpoint.init.delete(ctx, endpoint_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sns.endpoint.init.delete endpoint_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sns",
        operation="delete_endpoint",
        op_kwargs={"EndpointArn": endpoint_arn},
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


__func_alias__ = {"list_": "list"}


async def add(hub, ctx, resource_arn: str, tags: List) -> Dict:
    r"""
    **Autogenerated function**

    Adds or overwrites one or more tags for the specified Amazon SageMaker resource. You can add tags to notebook instances, training jobs, hyperparameter tuning jobs, batch transform jobs, models, labeling jobs, work teams, endpoint configurations, and endpoints. Each tag consists of a key and an optional value. Tag keys must be unique per resource. For more information about tags, see For more information, see Amazon Web Services Tagging Strategies.  Tags that you add to a hyperparameter tuning job by calling this API are also added to any training jobs that the hyperparameter tuning job launches after you call this API, but not to training jobs that the hyperparameter tuning job launched before you called this API. To make sure that the tags associated with a hyperparameter tuning job are also added to all training jobs that the hyperparameter tuning job launches, add the tags when you first create the tuning job by specifying them in the Tags parameter of CreateHyperParameterTuningJob    Tags that you add to a SageMaker Studio Domain or User Profile by calling this API are also added to any Apps that the Domain or User Profile launches after you call this API, but not to Apps that the Domain or User Profile launched before you called this API. To make sure that the tags associated with a Domain or User Profile are also added to all Apps that the Domain or User Profile launches, add the tags when you first create the Domain or User Profile by specifying them in the Tags parameter of CreateDomain or CreateUserProfile.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource that you want to tag.
        tags(List): An array of key-value pairs. You can use tags to categorize your Amazon Web Services resources in different ways, for example, by purpose, owner, or environment. For more information, see Tagging Amazon Web Services Resources.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.tags.add(ctx, resource_arn=value, tags=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.tags.add resource_arn=value, tags=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="add_tags",
        op_kwargs={"ResourceArn": resource_arn, "Tags": tags},
    )


async def delete(hub, ctx, resource_arn: str, tag_keys: List) -> Dict:
    r"""
    **Autogenerated function**

    Deletes the specified tags from an Amazon SageMaker resource. To list a resource's tags, use the ListTags API.   When you call this API to delete tags from a hyperparameter tuning job, the deleted tags are not removed from training jobs that the hyperparameter tuning job launched before you called this API.   When you call this API to delete tags from a SageMaker Studio Domain or User Profile, the deleted tags are not removed from Apps that the SageMaker Studio Domain or User Profile launched before you called this API.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource whose tags you want to delete.
        tag_keys(List): An array or one or more tag keys to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.tags.delete(ctx, resource_arn=value, tag_keys=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.tags.delete resource_arn=value, tag_keys=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="delete_tags",
        op_kwargs={"ResourceArn": resource_arn, "TagKeys": tag_keys},
    )


async def list_(
    hub, ctx, resource_arn: str, next_token: str = None, max_results: int = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns the tags for the specified Amazon SageMaker resource.

    Args:
        resource_arn(str): The Amazon Resource Name (ARN) of the resource whose tags you want to retrieve.
        next_token(str, optional):  If the response to the previous ListTags request is truncated, Amazon SageMaker returns this token. To retrieve the next set of tags, use it in the subsequent request. . Defaults to None.
        max_results(int, optional): Maximum number of tags to return. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.sagemaker.tags.list(ctx, resource_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.sagemaker.tags.list resource_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="sagemaker",
        operation="list_tags",
        op_kwargs={
            "ResourceArn": resource_arn,
            "NextToken": next_token,
            "MaxResults": max_results,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def delete(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a namespace from the current account. If the namespace still contains one or more services, the request fails.

    Args:
        id_(str): The ID of the namespace that you want to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.namespace.delete(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.namespace.delete id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="delete_namespace",
        op_kwargs={"Id": id_},
    )


async def get(hub, ctx, id_: str) -> Dict:
    r"""
    **Autogenerated function**

    Gets information about a namespace.

    Args:
        id_(str): The ID of the namespace that you want to get information about.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.namespace.get(ctx, id_=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.namespace.get id_=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="get_namespace",
        op_kwargs={"Id": id_},
    )


async def list_all(
    hub, ctx, next_token: str = None, max_results: int = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Lists summary information about the namespaces that were created by the current account.

    Args:
        next_token(str, optional): For the first ListNamespaces request, omit this value. If the response contains NextToken, submit another ListNamespaces request to get the next group of results. Specify the value of NextToken from the previous response in the next request.  Cloud Map gets MaxResults namespaces and then filters them based on the specified criteria. It's possible that no namespaces in the first MaxResults namespaces matched the specified criteria but that subsequent groups of MaxResults namespaces do contain namespaces that match the criteria. . Defaults to None.
        max_results(int, optional): The maximum number of namespaces that you want Cloud Map to return in the response to a ListNamespaces request. If you don't specify a value for MaxResults, Cloud Map returns up to 100 namespaces. Defaults to None.
        filters(List, optional): A complex type that contains specifications for the namespaces that you want to list. If you specify more than one filter, a namespace must match all filters to be returned by ListNamespaces. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.servicediscovery.namespace.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.servicediscovery.namespace.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="servicediscovery",
        operation="list_namespaces",
        op_kwargs={
            "NextToken": next_token,
            "MaxResults": max_results,
            "Filters": filters,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict
from typing import List


async def create(
    hub,
    ctx,
    source_location_arn: str,
    destination_location_arn: str,
    cloud_watch_log_group_arn: str = None,
    name: str = None,
    options: Dict = None,
    excludes: List = None,
    schedule: Dict = None,
    tags: List = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Creates a task. A task includes a source location and a destination location, and a configuration that specifies how data is transferred. A task always transfers data from the source location to the destination location. The configuration specifies options such as task scheduling, bandwidth limits, etc. A task is the complete definition of a data transfer. When you create a task that transfers data between AWS services in different AWS Regions, one of the two locations that you specify must reside in the Region where DataSync is being used. The other location must be specified in a different Region. You can transfer data between commercial AWS Regions except for China, or between AWS GovCloud (US-East and US-West) Regions.  When you use DataSync to copy files or objects between AWS Regions, you pay for data transfer between Regions. This is billed as data transfer OUT from your source Region to your destination Region. For more information, see Data Transfer pricing.

    Args:
        source_location_arn(str): The Amazon Resource Name (ARN) of the source location for the task.
        destination_location_arn(str): The Amazon Resource Name (ARN) of an AWS storage resource's location. .
        cloud_watch_log_group_arn(str, optional): The Amazon Resource Name (ARN) of the Amazon CloudWatch log group that is used to monitor and log events in the task. . Defaults to None.
        name(str, optional): The name of a task. This value is a text reference that is used to identify the task in the console. . Defaults to None.
        options(Dict, optional): The set of configuration options that control the behavior of a single execution of the task that occurs when you call StartTaskExecution. You can configure these options to preserve metadata such as user ID (UID) and group ID (GID), file permissions, data integrity verification, and so on. For each individual task execution, you can override these options by specifying the OverrideOptions before starting the task execution. For more information, see the StartTaskExecution operation. . Defaults to None.
        excludes(List, optional): A list of filter rules that determines which files to exclude from a task. The list should contain a single filter string that consists of the patterns to exclude. The patterns are delimited by "|" (that is, a pipe), for example, "/folder1|/folder2".   . Defaults to None.
        schedule(Dict, optional): Specifies a schedule used to periodically transfer files from a source to a destination location. The schedule should be specified in UTC time. For more information, see Scheduling your task. Defaults to None.
        tags(List, optional): The key-value pair that represents the tag that you want to add to the resource. The value can be an empty string. . Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.task.init.create(
                ctx, source_location_arn=value, destination_location_arn=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.task.init.create source_location_arn=value, destination_location_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="create_task",
        op_kwargs={
            "SourceLocationArn": source_location_arn,
            "DestinationLocationArn": destination_location_arn,
            "CloudWatchLogGroupArn": cloud_watch_log_group_arn,
            "Name": name,
            "Options": options,
            "Excludes": excludes,
            "Schedule": schedule,
            "Tags": tags,
        },
    )


async def delete(hub, ctx, task_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Deletes a task.

    Args:
        task_arn(str): The Amazon Resource Name (ARN) of the task to delete.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.task.init.delete(ctx, task_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.task.init.delete task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="delete_task",
        op_kwargs={"TaskArn": task_arn},
    )


async def describe(hub, ctx, task_arn: str) -> Dict:
    r"""
    **Autogenerated function**

    Returns metadata about a task.

    Args:
        task_arn(str): The Amazon Resource Name (ARN) of the task to describe.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.task.init.describe(ctx, task_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.task.init.describe task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="describe_task",
        op_kwargs={"TaskArn": task_arn},
    )


async def list_all(
    hub, ctx, max_results: int = None, next_token: str = None, filters: List = None
) -> Dict:
    r"""
    **Autogenerated function**

    Returns a list of all the tasks.

    Args:
        max_results(int, optional): The maximum number of tasks to return. Defaults to None.
        next_token(str, optional): An opaque string that indicates the position at which to begin the next list of tasks. Defaults to None.
        filters(List, optional): You can use API filters to narrow down the list of resources returned by ListTasks. For example, to retrieve all tasks on a specific source location, you can use ListTasks with filter name LocationId and Operator Equals with the ARN for the location. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.task.init.list_all(ctx)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.task.init.list_all
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="list_tasks",
        op_kwargs={
            "MaxResults": max_results,
            "NextToken": next_token,
            "Filters": filters,
        },
    )


async def update(
    hub,
    ctx,
    task_arn: str,
    options: Dict = None,
    excludes: List = None,
    schedule: Dict = None,
    name: str = None,
    cloud_watch_log_group_arn: str = None,
) -> Dict:
    r"""
    **Autogenerated function**

    Updates the metadata associated with a task.

    Args:
        task_arn(str): The Amazon Resource Name (ARN) of the resource name of the task to update.
        options(Dict, optional): Represents the options that are available to control the behavior of a StartTaskExecution operation. Behavior includes preserving metadata such as user ID (UID), group ID (GID), and file permissions, and also overwriting files in the destination, data integrity verification, and so on. A task has a set of default options associated with it. If you don't specify an option in StartTaskExecution, the default value is used. You can override the defaults options on each task execution by specifying an overriding Options value to StartTaskExecution. Defaults to None.
        excludes(List, optional): A list of filter rules that determines which files to exclude from a task. The list should contain a single filter string that consists of the patterns to exclude. The patterns are delimited by "|" (that is, a pipe), for example: "/folder1|/folder2"   . Defaults to None.
        schedule(Dict, optional): Specifies a schedule used to periodically transfer files from a source to a destination location. You can configure your task to execute hourly, daily, weekly or on specific days of the week. You control when in the day or hour you want the task to execute. The time you specify is UTC time. For more information, see Scheduling your task. Defaults to None.
        name(str, optional): The name of the task to update. Defaults to None.
        cloud_watch_log_group_arn(str, optional): The Amazon Resource Name (ARN) of the resource name of the CloudWatch LogGroup. Defaults to None.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.datasync.task.init.update(ctx, task_arn=value)

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.datasync.task.init.update task_arn=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="datasync",
        operation="update_task",
        op_kwargs={
            "TaskArn": task_arn,
            "Options": options,
            "Excludes": excludes,
            "Schedule": schedule,
            "Name": name,
            "CloudWatchLogGroupArn": cloud_watch_log_group_arn,
        },
    )



"""
Autogenerated module using `pop-create-idem <https://gitlab.com/saltstack/pop/pop-create-idem>`__
"""
from typing import Dict


async def update(hub, ctx, gateway_arn: str, smb_security_strategy: str) -> Dict:
    r"""
    **Autogenerated function**

    Updates the SMB security strategy on a file gateway. This action is only supported in file gateways.  This API is called Security level in the User Guide. A higher security level can affect performance of the gateway.

    Args:
        gateway_arn(str): The Amazon Resource Name (ARN) of the gateway. Use the ListGateways operation to return a list of gateways for your account and Region.
        smb_security_strategy(str): Specifies the type of security strategy. ClientSpecified: if you use this option, requests are established based on what is negotiated by the client. This option is recommended when you want to maximize compatibility across different clients in your environment. Supported only in S3 File Gateway. MandatorySigning: if you use this option, file gateway only allows connections from SMBv2 or SMBv3 clients that have signing enabled. This option works with SMB clients on Microsoft Windows Vista, Windows Server 2008 or newer. MandatoryEncryption: if you use this option, file gateway only allows connections from SMBv3 clients that have encryption enabled. This option is highly recommended for environments that handle sensitive data. This option works with SMB clients on Microsoft Windows 8, Windows Server 2012 or newer.

    Returns:
        Dict

    Examples:
        Call from code:

        .. code-block:: python

            await hub.exec.aws_auto.storagegateway.smb.security_strategy.update(
                ctx, gateway_arn=value, smb_security_strategy=value
            )

        Call from CLI:

        .. code-block:: bash

            $ idem exec aws_auto.storagegateway.smb.security_strategy.update gateway_arn=value, smb_security_strategy=value
    """
    return await hub.tool.aws.client.exec(
        ctx,
        service_name="storagegateway",
        operation="update_smb_security_strategy",
        op_kwargs={
            "GatewayARN": gateway_arn,
            "SMBSecurityStrategy": smb_security_strategy,
        },
    )
